EncryptedFile

Struct EncryptedFile 

pub struct EncryptedFile<R> { /* private fields */ }
An encrypted file.

Implementations

Source

impl<R> EncryptedFile<R>
where R: Read + Seek,

pub fn new(reader: R) -> Result<Self, Error>

Opens reader as an encrypted file.

This reads enough of the file to verify that it is in the expected format and returns an error if it cannot be read or is not the expected format.

reader doesn’t need to be BufRead, and probably should not be. The EncryptedReader returned by unlock or unlock_literal will be BufRead.

pub fn unlock<P>(self, password: P) -> Result<EncryptedReader<R>, Self>
where P: AsRef<[u8]>,

Tries to unlock the encrypted file using both password and with password decoded with EncodedPassword::decode. If successful, returns an EncryptedReader for the file; on failure, returns the EncryptedFile again for another try.

pub fn unlock_literal<P>(self, password: P) -> Result<EncryptedReader<R>, Self>
where P: AsRef<[u8]>,

Tries to unlock the encrypted file using just password. If successful, returns an EncryptedReader for the file; on failure, returns the EncryptedFile again for another try.

If the password itself might be encoded (“encrypted”), instead use Self::unlock to try it both ways.

pub fn file_type(&self) -> FileType

Returns the type of encrypted file.