CommandMatcher

Struct CommandMatcher 

pub struct CommandMatcher<'a, T> { /* private fields */ }
Matches a string against a collection of command names.

Implementations

Source

impl<'a, T> CommandMatcher<'a, T>

pub fn new(string: &'a str) -> Self

Creates a new matcher for string.

pub fn add(&mut self, command: &str, aux: T)

Consider command as a candidate for the command name being parsed. If command is the correct command name, then get_match will return aux later.

pub fn get_match(self) -> (Option<T>, isize)

Returns the best match among the possibilities passed to add. Also returns the number of additional words that the caller should consider reading, because the full command name might be longer (if a command was returned) or because more words might be needed for disambiguation (if no command name was returned).