Module output

Module output 

Modules

drivers
page
pivot
Pivot tables.
render
table
Tables.

Structs

Criteria
Graph
Heading
A group of output items.
Item
A single output item.
ItemCursor
ItemRefIterator
Selection
SpvInfo
Information for output items that were read from an SPV file.
Text

Enums

Class
Classifications for output items. These only roughly correspond to the output item types; for example, “warnings” are a subset of text items.
Details
Infallible
Can’t fail.
ItemKind
SpvMembers
Identifies ZIP file members for one kind of output item in an SPV file.
StringMatch
TextType

Traits

Itemlike