Data cell contents.
This module contains Value, which is the contents of a single pivot table cell, plus what it in turn contains.
Structs
- Bare
Value - Wrapper for Value that serializes in a plain way:
- Datum
Value - A datum and how to display it.
- Display
Value - Helper struct for printing a Value with
format!and{}. - Template
Value - A template with substitutions.
- Text
Value - A text string.
- Value
- The content of a single pivot table cell.
- Value
Options - Options for displaying a Value.
- Value
Style - Styling inside a Value.
- Variable
Value - A variable name.
Enums
- Value
Format - A Format inside a Value.
- Value
Inner - Possible content for a Value.