ValueInner

Enum ValueInner 

pub enum ValueInner {
    Datum(DatumValue),
    Variable(VariableValue),
    Text(TextValue),
    Markup(Markup),
    Template(TemplateValue),
    Empty,
}
Possible content for a Value.

Variants



Datum(DatumValue)

A Datum value.

Tuple Fields

0: DatumValue

The datum.



Variable(VariableValue)

A variable name.

Tuple Fields

0: VariableValue

The variable.



Text(TextValue)

Plain text.

Tuple Fields

0: TextValue

The text.



Markup(Markup)

Rich text.

Tuple Fields

0: Markup

The rich text.



Template(TemplateValue)

A template with substitutions.

Tuple Fields

0: TemplateValue

The template.



Empty

An empty value.

Implementations

Source

impl ValueInner

pub const fn is_empty(&self) -> bool

Returns true if this is a ValueInner::Empty.

pub fn with_format(self, format: impl Into<ValueFormat>) -> Self

Returns this value with its display format set to format, if it is a DatumValue.

pub fn datum(&self) -> Option<&Datum<WithEncoding<ByteString>>>

Returns the Datum inside this value, if it is a DatumValue.

pub fn label(&self) -> Option<&str>

Returns the value label or variable label inside this value, if it has one.

pub fn as_datum_value(&self) -> Option<&DatumValue>

Returns the DatumValue inside this value, if it is ValueInner::Datum.

pub fn as_datum_value_mut(&mut self) -> Option<&mut DatumValue>

Returns the DatumValue inside this value, mutably, if it is ValueInner::Datum.

pub fn as_variable_value(&self) -> Option<&VariableValue>

Returns the VariableValue inside this value, if it is ValueInner::Variable.

pub fn as_variable_value_mut(&mut self) -> Option<&mut VariableValue>

Returns the VariableValue inside this value, mutably, if it is ValueInner::Variable.

pub fn display(&self, options: impl Into<ValueOptions>) -> DisplayValue<'_>

Returns an object that will format this value. Settings on options control whether variable and value labels are included.

pub fn new_user_text(s: impl Into<String>) -> Self

Constructs a new text ValueInner from s, which should have been provided by the user.