DatumValue

Struct DatumValue 

pub struct DatumValue {
    pub datum: Datum<WithEncoding<ByteString>>,
    pub format: ValueFormat,
    pub show: Option<Show>,
    pub variable: Option<String>,
    pub value_label: Option<String>,
}
A datum and how to display it.

Fields

datum: Datum<WithEncoding<ByteString>>

The datum.

format: ValueFormat

The display format.

show: Option<Show>

Whether to show value or value_label or both.

If this is unset, then a higher-level default is used.

variable: Option<String>

The name of the variable that value came from, if any.

value_label: Option<String>

The value label associated with value, if any.

Implementations

Source

impl DatumValue

pub fn new<B>(datum: &Datum<B>) -> Self
where B: EncodedString,

Constructs a new DatumValue for datum.

pub fn new_number(number: Option<f64>) -> Self

Constructs a new DatumValue for number.

pub fn with_format(self, format: ValueFormat) -> Self

Returns this DatumValue with the given format.

pub fn display<'a>( &self, display: &DisplayValue<'a>, f: &mut Formatter<'_>, ) -> Result

Writes this value to f using the settings in display.

pub fn decimal(&self) -> Decimal

Returns the decimal point used in the formatted value, if any.

pub fn serialize_bare<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
where S: Serializer,

Serializes this value to serializer in the “bare” manner described for BareValue.