pub struct Heading(pub Vec<Arc<Item>>);Expand description
A group of output items.
The name “heading” is used in SPV files. There is only a visible heading if the output items inside the heading include a Text item. The grouping itself is only visible in the outline pane in a viewer window.
Tuple Fields
0: Vec<Arc<Item>>Implementations