Module table

Module table 

Tables.

A table is a rectangular grid of cells. Cells can be joined to form larger cells. Rows and columns can be separated by rules of various types. Rows at the top and bottom of a table and columns at the left and right edges of a table can be designated as headers, which means that if the table must be broken across more than one page, those rows or columns are repeated on each page.

Some drivers use tables as an implementation detail of rendering pivot tables.

Structs

Cell
CellInner
CellPos
The (x,y) position of a cell in a Table.
CellRect
A rectangular group of cells in a Table.
CellRef
Cells
Iterator for all of the cells in a table (see Table::cells).
DrawCell
Table
A table.
XIter

Enums

Content