Style

Enum Style 

pub enum Style {
    Bold,
    Italic,
    Underline,
    Strike,
    Emphasis,
    Strong,
    Face(String),
    Color(Color),
    Size(f64),
}
A text style.

Used in Markup::Style.

Variants



Bold

Bold.



Italic

Italic.



Underline

Underline.



Strike

Strikethrough.



Emphasis

Emphasis.



Strong

Strong.



Face(String)

Sets the typeface.

Tuple Fields

0: String

The typeface name.



Color(Color)

Font color.

Tuple Fields

0: Color

The color



Size(f64)

Font size.

Tuple Fields

0: f64

In 1/72“ units.

Implementations

Source

impl Style

pub fn parse_css(css: &str) -> Vec<Style>

Parses the CSS found in css and returns the corresponding Styles.

This is only good enough to parse the simple CSS found in SPV files.