pub struct SpvOutline {
pub page_setup: Option<PageSetup>,
pub items: Vec<OutlineItem>,
}Expand description
An outline of an SPV file.
Reading the outline only requires reading some of the SPV file. It provides a “table of contents” view of the SPV, without reading the details of tables and graphs.
Fields
page_setup: Option<PageSetup>Optional page setup, from the first structure member.
items: Vec<OutlineItem>The table of contents.