Module records

Module records 

Raw records.

Separated into a submodule just to reduce clutter.

Structs

Attribute
A file or variable attribute in a system file.
DocumentRecord
A document record in a system file.
EncodingRecord
A character encoding record in a system file.
Extension
An extension record in a system file.
ExtensionRecord
Constraints on an extension record in a system file.
FileAttributesRecord
A decoded file attributes record in a system file.
FileHeader
A file header record in a system file.
FloatInfoRecord
A floating-point info record.
IntegerInfoRecord
An integer info record in a system file.
LongName
A long variable name in a system file.
LongNamesRecord
A long variable name record in a system file.
LongStringMissingValueRecord
Long string missing values record in a sytem file.
LongStringMissingValues
Missing values for one long string variable.
LongStringValueLabelRecord
A long string value labels record in a system file.
LongStringValueLabels
One set of long string value labels record in a system file.
MultipleResponseRecord
A multiple-response set record in a system file.
MultipleResponseSet
A multiple-response set in a system file.
NumberOfCasesRecord
The extended number of cases record in a system file.
ProductInfoRecord
A product info record in a system file.
RawFileAttributesRecord
A raw (text) file attributes record in a system file.
RawFormat
Format as represented in a system file.
RawHeader
Raw file header.
RawIntegerInfoRecord
Machine integer info record in binrw format.
RawLongNamesRecord
Long variable names record.
RawMissingValues
Missing values in a VariableRecord.
RawProductInfoRecord
Raw (text) version of a product info record in a system file.
RawVariableAttributesRecord
A raw (text) variable attributes record in a system file.
RawVariableRecord
Raw variable record.
RawVariableSetRecord
Raw (text) version of the variable set record in a system file.
RawVeryLongStringsRecord
A very long string record as text.
RawZHeader
A ZLIB header in a system file.
RawZTrailer
A ZLIB trailer in a system file.
TextRecord
An extension record whose contents are a text string.
ValueLabel
A value and label in a system file.
ValueLabelRecord
A value label record in a system file.
VarAttributes
A set of variable attributes in a system file.
VarDisplay
Variable display settings for one variable, in a system file.
VarDisplayRecord
A variable display record in a system file.
VariableAttributesRecord
A decoded variable attributes record in a system file.
VariableRecord
A variable record in a system file.
VariableSet
A variable set in a system file.
VariableSetRecord
A variable set record in a system file.
VeryLongString
A very long string parsed from a VeryLongStringsRecord.
VeryLongStringError
Cannot convert very long string (wider than 255 bytes) to RawFormat.
VeryLongStringsRecord
A parsed very long string record.
ZBlock
A ZLIB block descriptor in a system file.
ZHeader
ZLIB header, for Compression::ZLib.
ZTrailer
A ZLIB trailer in a system file.

Enums

AttributeWarning
Warning for a file or variable attribute record.
Compression
Type of compression in a system file.
ExtensionWarning
Warning for an extension record.
HeaderWarning
A warning for a file header.
LongNameWarning
Warning for a long variable name record.
LongStringMissingValuesWarning
Warning for a long string missing value record.
LongStringValueLabelWarning
Warning for a long string value label record.
MultipleResponseType
The type of a multiple-response set.
MultipleResponseWarning
Warning for a multiple response set record.
ValueLabelWarning
Warning for a value label record.
VariableDisplayWarning
Warning for a variable display record.
VariableSetWarning
Warning for a variable sets record.
VariableWarning
Warning for a variable record.
VeryLongStringWarning
Warning for a very long string variable record.
ZHeaderError
Error reading a ZHeader.
ZTrailerError
Error reading a ZTrailer.
ZlibTrailerWarning
Warning for a ZLIB trailer record.

Constants

DOC_LINE_LEN
Length of a line in a document. Document lines are fixed-length and padded on the right with spaces.

Type Aliases

RawDocumentLine
One line in a document.