VarWidth

Enum VarWidth 

pub enum VarWidth {
    Numeric,
    String(u16),
}
A variable’s width.

This is essentially VarType plus a width for VarType::String.

Variants



Numeric

A numeric variable.



String(u16)

A string variable.

Tuple Fields

0: u16

The width of the string variable.

Must be in 1..=32767, although the type system does not yet enforce this.

Implementations

Source

impl VarWidth

pub const MAX_STRING: u16 = 32767

pub const SEGMENT_SIZE: usize = 252

Number of bytes per segment by which the amount of space for very long string variables is allocated.

pub fn n_dict_indexes(self) -> usize

pub fn wider(a: VarWidth, b: VarWidth) -> Option<VarWidth>

Returns the wider of self and other:

  • Numerical variable widths are equally wide.
  • Longer strings are wider than shorter strings.
  • Numerical and string types are incomparable, so result in None.
pub fn narrower(a: VarWidth, b: VarWidth) -> Option<VarWidth>

Returns the narrower of self and other (see Self::wider).

pub fn default_display_width(&self) -> u32

pub fn is_long_string(&self) -> bool

pub fn as_string_width(&self) -> Option<usize>

pub fn is_numeric(&self) -> bool

pub fn is_string(&self) -> bool

pub fn is_very_long_string(&self) -> bool

Returns true if this is a very long string width, meaning wider than 255 bytes, which was the limit for old versions of SPSS.

pub fn segments(&self) -> Segments

Returns an iterator over the “segments” used for writing case data for a variable with this width. A segment is a physical variable in the system file that represents some piece of a logical variable as seen by a PSPP user. Most variables have one segment whose width is their own width, but very long string variables, with width greater than 255, have multiple segments each with width 255 or less.

pub fn n_chunks(&self) -> Option<usize>

Returns the number of 8-byte chunks used for writing case data for a variable with this width. Very long string variables (wider than 255 bytes) cannot directly be divided into chunks: they must first be divided into multiple segments, which can then be divided into chunks.

pub fn segment_alloc_width(&self, segment_idx: usize) -> usize

Returns the width to allocate to the segment with the given segment_idx within this variable. A segment is a physical variable in the system file that represents some piece of a logical variable as seen by a PSPP user.

pub fn display_adjective(&self) -> VarWidthAdjective

pub fn codepage_to_unicode(&mut self)