pub struct CommandMatcher<'a, T> { /* private fields */ }Expand description
Matches a string against a collection of command names.
Implementations
Sourceimpl<'a, T> CommandMatcher<'a, T>
impl<'a, T> CommandMatcher<'a, T>
Sourcepub fn add(&mut self, command: &str, aux: T)
pub fn add(&mut self, command: &str, aux: T)
Consider command as a candidate for the command name being parsed. If
command is the correct command name, then get_match
will return aux later.
Sourcepub fn get_match(self) -> (Option<T>, isize)
pub fn get_match(self) -> (Option<T>, isize)
Returns the best match among the possibilities passed to add. Also returns the number of additional words that the caller should consider reading, because the full command name might be longer (if a command was returned) or because more words might be needed for disambiguation (if no command name was returned).