pub enum Punct {
Show 35 variants
Plus,
Dash,
Asterisk,
Slash,
Equals,
LParen,
RParen,
LSquare,
RSquare,
LCurly,
RCurly,
Comma,
Semicolon,
Colon,
And,
Or,
Not,
Eq,
Ge,
Gt,
Le,
Lt,
Ne,
All,
By,
To,
With,
Exp,
Bang,
Percent,
Question,
Backtick,
Dot,
Underscore,
BangAsterisk,
}Expand description
An operator, punctuator, or reserved word.
Variants
Plus
+.
Dash
-.
Asterisk
*.
Slash
/.
Equals
=.
LParen
(.
RParen
).
LSquare
[.
RSquare
].
LCurly
{.
RCurly
}.
Comma
,.
Semicolon
;.
Colon
:.
And
AND or &.
Or
OR or |.
Not
NOT or ~.
Eq
EQ or =.
Ge
GE or ’>=`
Gt
GT or >.
Le
LE or <=.
Lt
LT or <.
Ne
NE or ~= or <>.
All
ALL.
By
BY.
To
TO.
With
WITH.
Exp
**.
Bang
! (only appears in macros).
Percent
% (only appears in macros).
Question
? (only appears in macros).
Backtick
` (only appears in macros).
Dot
..
This represents a dot in the middle of a line by itself, where it does not end a command.
Underscore
_ (only appears in macros).
Although underscores may appear within identifiers, they can’t be the first character, so this represents an underscore found on its own.
BangAsterisk
!* (only appears in macros).
Implementations