pub struct SyntaxFile { /* private fields */ }Expand description
A syntax file and its contents.
This holds the entire contents of a syntax file, which are always read into memory in their entirety, recoded into UTF-8 if necessary. It includes the file name (if any), and an index to make finding lines by line number more efficient.
Implementations
Sourceimpl SyntaxFile
impl SyntaxFile
Sourcepub fn for_file<P>(
path: P,
encoding: Option<&'static Encoding>,
) -> IoResult<Self>
pub fn for_file<P>( path: P, encoding: Option<&'static Encoding>, ) -> IoResult<Self>
Returns a SyntaxFile by reading path and recoding it from
encoding.
Sourcepub fn new(
contents: String,
file_name: Option<String>,
encoding: &'static Encoding,
) -> Self
pub fn new( contents: String, file_name: Option<String>, encoding: &'static Encoding, ) -> Self
Creates a new SyntaxFile for contents, recording that contents was
originally encoded in encoding and that it was read from file_name.
Sourcepub fn for_string(contents: String) -> Self
pub fn for_string(contents: String) -> Self
Returns a SyntaxFile for contents.