pub struct Footnote {
pub content: Box<Value>,
pub marker: Option<Box<Value>>,
pub show: bool,
/* private fields */
}Expand description
A footnote in a PivotTable.
A footnote is attached directly to a Value, but it will only be displayed correctly if it is also added to PivotTable::footnotes for its pivot table.
Fields
content: Box<Value>The footnote text.
marker: Option<Box<Value>>The footnote marker.
This is usually None, in which case FootnoteMarkerType determines
the default marker.
show: boolWhether to show the footnote.
Implementations
Sourceimpl Footnote
impl Footnote
Sourcepub fn with_marker(self, marker: Option<Value>) -> Self
pub fn with_marker(self, marker: Option<Value>) -> Self
Returns the footnote with the given optional marker.
Sourcepub fn with_some_marker(self, marker: impl Into<Value>) -> Self
pub fn with_some_marker(self, marker: impl Into<Value>) -> Self
Returns the footnote with the given marker.
Sourcepub fn with_index(self, index: usize) -> Self
pub fn with_index(self, index: usize) -> Self
Return the footnote with the given index.
Sourcepub fn display_marker(&self, options: impl Into<ValueOptions>) -> impl Display
pub fn display_marker(&self, options: impl Into<ValueOptions>) -> impl Display
Returns an object for formatting the footnote’s marker.
Sourcepub fn display_content(&self, options: impl Into<ValueOptions>) -> impl Display
pub fn display_content(&self, options: impl Into<ValueOptions>) -> impl Display
Returns an object for formatting the footnote’s text.