Module value

Module value 

Data cell contents.

This module contains Value, which is the contents of a single pivot table cell, plus what it in turn contains.

Structs

BareValue
Wrapper for Value that serializes in a plain way:
DatumValue
A datum and how to display it.
DisplayValue
Helper struct for printing a Value with format! and {}.
TemplateValue
A template with substitutions.
TextValue
A text string.
Value
The content of a single pivot table cell.
ValueOptions
Options for displaying a Value.
ValueStyle
Styling inside a Value.
VariableValue
A variable name.

Enums

ValueFormat
A Format inside a Value.
ValueInner
Possible content for a Value.