Raw records.
Separated into a submodule just to reduce clutter.
Structs
- Attribute
- A file or variable attribute in a system file.
- Document
Record - A document record in a system file.
- Encoding
Record - A character encoding record in a system file.
- Extension
- An extension record in a system file.
- Extension
Record - Constraints on an extension record in a system file.
- File
Attributes Record - A decoded file attributes record in a system file.
- File
Header - A file header record in a system file.
- Float
Info Record - A floating-point info record.
- Integer
Info Record - An integer info record in a system file.
- Long
Name - A long variable name in a system file.
- Long
Names Record - A long variable name record in a system file.
- Long
String Missing Value Record - Long string missing values record in a sytem file.
- Long
String Missing Values - Missing values for one long string variable.
- Long
String Value Label Record - A long string value labels record in a system file.
- Long
String Value Labels - One set of long string value labels record in a system file.
- Multiple
Response Record - A multiple-response set record in a system file.
- Multiple
Response Set - A multiple-response set in a system file.
- Number
OfCases Record - The extended number of cases record in a system file.
- Product
Info Record - A product info record in a system file.
- RawFile
Attributes Record - A raw (text) file attributes record in a system file.
- RawFormat
- Format as represented in a system file.
- RawHeader
- Raw file header.
- RawInteger
Info Record - Machine integer info record in binrw format.
- RawLong
Names Record - Long variable names record.
- RawMissing
Values - Missing values in a VariableRecord.
- RawProduct
Info Record - Raw (text) version of a product info record in a system file.
- RawVariable
Attributes Record - A raw (text) variable attributes record in a system file.
- RawVariable
Record - Raw variable record.
- RawVariable
SetRecord - Raw (text) version of the variable set record in a system file.
- RawVery
Long Strings Record - A very long string record as text.
- RawZ
Header - A ZLIB header in a system file.
- RawZ
Trailer - A ZLIB trailer in a system file.
- Text
Record - An extension record whose contents are a text string.
- Value
Label - A value and label in a system file.
- Value
Label Record - A value label record in a system file.
- VarAttributes
- A set of variable attributes in a system file.
- VarDisplay
- Variable display settings for one variable, in a system file.
- VarDisplay
Record - A variable display record in a system file.
- Variable
Attributes Record - A decoded variable attributes record in a system file.
- Variable
Record - A variable record in a system file.
- Variable
Set - A variable set in a system file.
- Variable
SetRecord - A variable set record in a system file.
- Very
Long String - A very long string parsed from a VeryLongStringsRecord.
- Very
Long String Error - Cannot convert very long string (wider than 255 bytes) to RawFormat.
- Very
Long Strings Record - A parsed very long string record.
- ZBlock
- A ZLIB block descriptor in a system file.
- ZHeader
- ZLIB header, for Compression::ZLib.
- ZTrailer
- A ZLIB trailer in a system file.
Enums
- Attribute
Warning - Warning for a file or variable attribute record.
- Compression
- Type of compression in a system file.
- Extension
Warning - Warning for an extension record.
- Header
Warning - A warning for a file header.
- Long
Name Warning - Warning for a long variable name record.
- Long
String Missing Values Warning - Warning for a long string missing value record.
- Long
String Value Label Warning - Warning for a long string value label record.
- Multiple
Response Type - The type of a multiple-response set.
- Multiple
Response Warning - Warning for a multiple response set record.
- Value
Label Warning - Warning for a value label record.
- Variable
Display Warning - Warning for a variable display record.
- Variable
SetWarning - Warning for a variable sets record.
- Variable
Warning - Warning for a variable record.
- Very
Long String Warning - Warning for a very long string variable record.
- ZHeader
Error - Error reading a ZHeader.
- ZTrailer
Error - Error reading a ZTrailer.
- Zlib
Trailer Warning - Warning for a ZLIB trailer record.
Constants
- DOC_
LINE_ LEN - Length of a line in a document. Document lines are fixed-length and padded on the right with spaces.
Type Aliases
- RawDocument
Line - One line in a document.